import { RequestHandler } from 'express';
import { ProductService } from '@/services/product.service';
import { plainToInstance } from 'class-transformer';
import { ProductDto } from '@/dto/ProductDto';

export class ProductController {
  private service: ProductService;

  constructor() {
    this.service = new ProductService();
  }

  getProducts: RequestHandler = async (req, res): Promise<void> => {
    const products = await this.service.getProducts();
    res.send(products);
  };

  getProduct: RequestHandler = async (req, res): Promise<void> => {
    try {
      const product = await this.service.getProduct(Number(req.params.id));
      res.send(product);
    } catch (e) {
      res.status(400).send({ message: (e as Error).message });
    }
  };

  createProduct: RequestHandler = async (req, res): Promise<void> => {
    const productDto = plainToInstance(ProductDto, req.body);
    if (req.file) productDto.image = req.file.filename;
    const product = await this.service.createProduct(productDto);
    res.send(product);
  };
}
