import { IProduct } from '@/interfaces/IProduct.interface';
import { ProductDto } from '@/dto/ProductDto';
import { Repository } from 'typeorm';
import { appDataSource } from '@/config/dataSource';
import { Product } from '@/entities/product.entity';

export class ProductRepository extends Repository<Product> {
  constructor() {
    super(Product, appDataSource.createEntityManager());
  }
  async getProducts(): Promise<IProduct[]> {
    return await this.find();
  }

  async getProduct(id: number): Promise<IProduct> {
    const product = await this.findOne({
      where: { id },
    });
    if (!product) {
      throw new Error('Продукта с таким id не существует');
    }

    return product;
  }

  async createProduct(productDto: ProductDto): Promise<IProduct> {
    const { title, description, price, image } = productDto;
    const product = new Product();
    product.image = image;
    product.title = title;
    product.price = price;
    product.description = description;

    await this.save(product);
    return product;
  }
}
